#
# spec file for package python-requirements-detector
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-requirements-detector
Version:        1.2.2
Release:        1.2
Summary:        Python tool to find and list requirements of a Python project
License:        MIT
URL:            https://github.com/landscapeio/requirements-detector
Source:         https://github.com/landscapeio/requirements-detector/archive/%{version}.tar.gz
Patch0:         fix-astroid-import.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-astroid >= 2.0
Requires:       python-packaging >= 21.3
Requires:       python-semver >= 3
Requires:       python-toml >= 0.10
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module astroid >= 2.0}
BuildRequires:  %{python_module packaging >= 21.3}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module semver >= 3}
BuildRequires:  %{python_module toml >= 0.10}
# /SECTION
%python_subpackages

%description
Requirements-detector is a Python tool which attempts to find and list
the requirements of a Python project.

When run from the root of a Python project, it will try to ascertain
which libraries and the versions of those libraries that the project
depends on.

%prep
%autosetup -p1 -n requirements-detector-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/detect-requirements
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative detect-requirements

%postun
%python_uninstall_alternative detect-requirements

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/requirements_detector
%{python_sitelib}/requirements_detector-%{version}.dist-info
%python_alternative %{_bindir}/detect-requirements

%changelog
* Wed Mar 27 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.2.2:
  * Stop polluting site-packages (see python-poetry/poetry#2015)
  * Added semver as a dependency as it is needed by the (transplanted)
    former poetry-semver code
  * remove poetry-semver from the list of deps
  * Updating packaging requirement in poetry lock file
  * Consolidating new version and poetry dependencies after merging some PRs
  * Output the dependency name without a version for poetry git, path and
    url dependencies
  * Tidying up some type hinting and heeding mypy warnings
  * Fixing all public API methods to handle str or Path arguments
  * Fixing from_setup_py to handle string and Path arguments
  * Fixing handling of >=X style version ranges
  * Added note about pyproject / poetry parsing
  * Re-adding 3.6; prospector still supports it for now
  * Handling parsing a requirements.txt generated by "poetry export"
  * More refactoring, adding some type hints, moving towards astroid 2+
    only compatibility
  * Refactoring setup.py handling to separate module to make testing easier
  * Cleaning up unused setup.py ; fixing pre-commit
- Add patch fix-astroid-import.patch:
  * Use correct exception name from Astroid.
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
* Wed Feb 10 2021 Markéta Machová <mmachova@suse.com>
- Get rid of %%ifpython3
- Drop the conflict, the old version is only on Leap 15.1 and older by now
* Mon Aug  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 0.7
  * support Python 3.8
  * code refactorings and cleanups
* Wed Jun  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- replace nose with pytest
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Jan 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Revert back the previous commit
* Thu Jan  9 2020 Todd R <toddrme2178@gmail.com>
- Drop python2 subpackage due to dependencies dropping python2.
* Tue May 21 2019 Todd R <toddrme2178@gmail.com>
- Fix conflicts with old python2-only version
- Fix description formatting.
* Mon May 20 2019 pgajdos@suse.com
- version update to 0.6
  * no changelog available
- run tests
- convert to singlespec
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 0.4:
  * no changelog available
* Wed Jan 15 2014 speilicke@suse.com
- Initial version
